@@ -1558,9 +1558,9 @@ static bool swapBufferEntry(int32_t a, int32_t b) // used for sorting
 	if (a >= FReq_FileCount || b >= FReq_FileCount)
 		return false;
 
-	DirRec tmpBuffer = FReq_Buffer[a];
+	DirRec tmp = FReq_Buffer[a];
 	FReq_Buffer[a] = FReq_Buffer[b];
-	FReq_Buffer[b] = tmpBuffer;
+	FReq_Buffer[b] = tmp;
 
 	return true;
 }
@@ -1712,7 +1712,7 @@ static void printFormattedFilesize(uint16_t x, uint16_t y, uint32_t bufEntry)
 		return;
 	}
 
-	assert(filesize >= 0);
+	ASSERT(filesize >= 0);
 
 	if (filesize >= 1024*1024*10) // >= 10MB?
 	{
@@ -1771,9 +1771,7 @@ static void displayCurrPath(void)
 #ifdef _WIN32
 		memcpy(FReq_NameTemp, p, 3); // get drive (f.ex. C:\)
 		FReq_NameTemp[3] = '\0';
-
-		strcat(FReq_NameTemp, ".\001"); // special character in font
-		FReq_NameTemp[5] = '\0';
+		strcat(FReq_NameTemp, "..\\");
 #else
 		FReq_NameTemp[0] = '\0';
 		strcpy(FReq_NameTemp, "/");
@@ -1899,7 +1897,7 @@ static DirRec *bufferCreateEmptyDir(void) // special case: creates a dir entry w
 
 static int32_t SDLCALL diskOp_ReadDirectoryThread(void *ptr)
 {
-	DirRec tmpBuffer;
+	DirRec tmp;
 
 	FReq_DirPos = 0;
 
@@ -1909,7 +1907,7 @@ static int32_t SDLCALL diskOp_ReadDirectoryThread(void *ptr)
 	UNICHAR_GETCWD(FReq_CurPathU, PATH_MAX);
 
 	// read first file
-	int8_t lastFindFileFlag = findFirst(&tmpBuffer);
+	int8_t lastFindFileFlag = findFirst(&tmp);
 	if (lastFindFileFlag != LFF_DONE && lastFindFileFlag != LFF_SKIP)
 	{
 		FReq_Buffer = (DirRec *)malloc(sizeof (DirRec));
@@ -1929,14 +1927,14 @@ static int32_t SDLCALL diskOp_ReadDirectoryThread(void *ptr)
 			return false;
 		}
 
-		memcpy(FReq_Buffer, &tmpBuffer, sizeof (DirRec));
+		memcpy(FReq_Buffer, &tmp, sizeof (DirRec));
 		FReq_FileCount++;
 	}
 
 	// read remaining files
 	while (lastFindFileFlag != LFF_DONE)
 	{
-		lastFindFileFlag = findNext(&tmpBuffer);
+		lastFindFileFlag = findNext(&tmp);
 		if (lastFindFileFlag != LFF_DONE && lastFindFileFlag != LFF_SKIP)
 		{
 			DirRec *newPtr = (DirRec *)realloc(FReq_Buffer, sizeof (DirRec) * (FReq_FileCount + 1));
@@ -1949,7 +1947,7 @@ static int32_t SDLCALL diskOp_ReadDirectoryThread(void *ptr)
 
 			FReq_Buffer = newPtr;
 
-			memcpy(&FReq_Buffer[FReq_FileCount], &tmpBuffer, sizeof (DirRec));
+			memcpy(&FReq_Buffer[FReq_FileCount], &tmp, sizeof (DirRec));
 			FReq_FileCount++;
 		}
 	}
@@ -2209,11 +2207,13 @@ static void drawDiskOpScreen(void)
 	showPushButton(PB_DISKOP_EXIT);
 	showPushButton(PB_DISKOP_PARENT);
 	showPushButton(PB_DISKOP_ROOT);
-	showPushButton(PB_DISKOP_SHOW_ALL);
 	showPushButton(PB_DISKOP_SET_PATH);
 	showPushButton(PB_DISKOP_LIST_UP);
 	showPushButton(PB_DISKOP_LIST_DOWN);
 
+	showCheckBox(CB_DISKOP_SHOW_ALL);
+	textOutShadow(85, 108, PAL_FORGRND, PAL_DSKTOP2, "All files");
+
 	showScrollBar(SB_DISKOP_LIST);
 	showTextBox(TB_DISKOP_FILENAME);
 
@@ -2250,7 +2250,7 @@ void showDiskOpScreen(void)
 	// if first time opening Disk Op., set initial directory
 	if (firstTimeOpeningDiskOp)
 	{
-		assert(FReq_ModCurPathU != NULL);
+		ASSERT(FReq_ModCurPathU != NULL);
 
 		// first test if we can change the dir to the one stored in the config (if present)
 		if (FReq_ModCurPathU[0] == '\0' || UNICHAR_CHDIR(FReq_ModCurPathU) != 0)
@@ -2308,11 +2308,12 @@ void hideDiskOpScreen(void)
 	hidePushButton(PB_DISKOP_EXIT);
 	hidePushButton(PB_DISKOP_PARENT);
 	hidePushButton(PB_DISKOP_ROOT);
-	hidePushButton(PB_DISKOP_SHOW_ALL);
 	hidePushButton(PB_DISKOP_SET_PATH);
 	hidePushButton(PB_DISKOP_LIST_UP);
 	hidePushButton(PB_DISKOP_LIST_DOWN);
 
+	hideCheckBox(CB_DISKOP_SHOW_ALL);
+
 	hideScrollBar(SB_DISKOP_LIST);
 	hideTextBox(TB_DISKOP_FILENAME);
 	hideRadioButtonGroup(RB_GROUP_DISKOP_ITEM);
@@ -2375,9 +2376,9 @@ void pbDiskOpRoot(void)
 #endif
 }
 
-void pbDiskOpShowAll(void)
+void cbDiskOpAllFiles(void)
 {
-	FReq_ShowAllFiles = true;
+	FReq_ShowAllFiles ^= 1;
 	editor.diskOpReadDir = true; // refresh dir
 }
 
