@@ -3,7 +3,9 @@
 #include <SDL2/SDL.h>
 #include <stdint.h>
 #include <stdbool.h>
+#ifdef _DEBUG
 #include <assert.h>
+#endif
 #ifdef _WIN32
 #define WIN32_MEAN_AND_LEAN
 #include <windows.h>
@@ -12,8 +14,8 @@
 #endif
 #include "ft2_replayer.h"
 
-#define PROG_VER_STR "2.04"
-#define PROG_VER_DATE "11 February 2026"
+#define PROG_VER_STR "2.05"
+#define PROG_VER_DATE "22 February 2026"
 
 // do NOT change these! It will only mess things up...
 
@@ -26,6 +28,14 @@
 #define SCALE_VBLANK_DELTA(x) (int32_t)(((x) * (FT2_VBLANK_HZ / (double)VBLANK_HZ)) + 0.5)
 #define SCALE_VBLANK_DELTA_REV(x) (int32_t)(((x) * (VBLANK_HZ / (double)FT2_VBLANK_HZ)) + 0.5)
 
+#ifndef ASSERT
+#ifdef _DEBUG
+#define ASSERT(x) assert(x)
+#else
+#define ASSERT(x)
+#endif
+#endif
+
 /* Amount of extra bytes to allocate for every instrument sample,
 ** this is used for a hack for resampling interpolation to be
 ** branchless in the inner channel mixer loop.
